@@ -35,7 +35,7 @@ class SaleOpportunity(ModelWorkflow, ModelSQL, ModelView):
     _rec_name = 'description'
 
     party = fields.Many2One('party.party', 'Party', required=True, select=1,
-            states=_STATES_STOP, depends=_DEPENDS_STOP)
+        on_change=['party'], states=_STATES_STOP, depends=_DEPENDS_STOP)
     address = fields.Many2One('party.address', 'Address',
         domain=[('party', '=', Eval('party'))],
         select=2, depends=['party', 'state'],
@@ -177,8 +177,8 @@ class SaleOpportunity(ModelWorkflow, ModelSQL, ModelView):
         res = {
             'payment_term': False,
         }
-        if vals.get('party'):
-            party = party_obj.browse(vals['party'])
+        if values.get('party'):
+            party = party_obj.browse(values['party'])
             if party.payment_term:
                 res['payment_term'] = party.payment_term.id
         if not res['payment_term']:
